Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(56)

Unified Diff: ios/chrome/browser/payments/payment_request_utils.h

Issue 2588913002: EarlGrey tests for Payment Request (base CL) (Closed)
Patch Set: Addressed comments by jdonnelly@ Created 3 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/payments/payment_request_utils.h
diff --git a/ios/chrome/browser/payments/payment_request_utils.h b/ios/chrome/browser/payments/payment_request_utils.h
index f47e1c6a3aaf684449ef600a1a6805d6503a3aba..e47eda15231269ebf9044db7c8a09b8a8a2a6ccb 100644
--- a/ios/chrome/browser/payments/payment_request_utils.h
+++ b/ios/chrome/browser/payments/payment_request_utils.h
@@ -13,9 +13,16 @@ class AutofillProfile;
namespace payment_request_utils {
-// Helper function to get the shipping address label from an autofill profile.
+// Helper function to get the name label from an autofill profile.
+NSString* NameLabelFromAutofillProfile(autofill::AutofillProfile* profile);
+
+// Helper function to get the address label from an autofill profile.
NSString* AddressLabelFromAutofillProfile(autofill::AutofillProfile* profile);
+// Helper function to get the phone number label from an autofill profile.
+NSString* PhoneNumberLabelFromAutofillProfile(
+ autofill::AutofillProfile* profile);
+
} // namespace payment_request_utils
#endif // IOS_CHROME_BROWSER_PAYMENTS_PAYMENT_REQUEST_UTILS_H_

Powered by Google App Engine
This is Rietveld 408576698